=====
Bodhi
=====

Welcome to Bodhi, Fedora's update gating system.


Documentation
=============

You can read Bodhi's
`release notes <https://bodhi.fedoraproject.org/docs/user/release_notes.html>`_
and documentation
`online <https://bodhi.fedoraproject.org/docs>`_, or by installing it on your
Fedora system and pointing your browser at
``/usr/share/doc/bodhi-docs/html/index.html``::

    $ sudo dnf install bodhi-docs && firefox /usr/share/doc/bodhi-docs/html/index.html

If you are interested in contributing to Bodhi, you can read the
`developer documentation`_.

.. _developer documentation: https://bodhi.fedoraproject.org/docs/developer/index.html


IRC
===

Come join us on `Freenode <https://webchat.freenode.net/>`_! We've got two channels:

* #bodhi - We use this channel to discuss upstream bodhi development
* #fedora-apps - We use this channel to discuss Fedora's Bodhi deployment (it is more generally
  about all of Fedora's infrastructure applications.)
